@@ -1,4 +1,4 @@
-vfgrayscale <- function( vf, age, pattern, algorithm ) {
+vfgrayscale <- function( sens, age, pattern, algorithm ) {
 
 # get the norm data and calculate normal age-corrected sensitivities
   texteval <- paste( "nv$", pattern, "_", algorithm, "$agelm", sep = "" )
@@ -6,8 +6,9 @@ vfgrayscale <- function( vf, age, pattern, algorithm ) {
   vals     <- agelm$intercept + agelm$slope * age
   idx      <- which( is.na( vals ) )
   if( length( idx ) > 0 ) vals <- vals[-idx]
-  vf <- as.numeric( vf )
-  vf <- vf / max( vals )
-  vf[which( vf > 1 )] <- 1
-  return ( matrix( rep( vf, 3 ), nrow = length( vf ), ncol = 3 ) )
+  sens <- as.numeric( sens )
+  sens <- sens / max( vals )
+  sens[which( sens < 0 )] <- 0
+  sens[which( sens > 1 )] <- 1
+  return ( matrix( rep( sens, 3 ), nrow = length( sens ), ncol = 3 ) )
 }
